package epson.print.screen;

import android.content.ComponentName;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.SharedPreferences;
import android.content.res.Configuration;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.RemoteException;
import android.os.SystemClock;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.epson.mobilephone.common.escpr.EscprError;
import com.epson.mobilephone.common.escpr.MediaInfo;
import com.epson.mobilephone.common.wifidirect.WiFiDirectManager;
import epson.common.Constants;
import epson.common.ExternalFileUtils;
import epson.common.Utils;
import epson.print.ActivityIACommon;
import epson.print.R;
import epson.print.EPPrinterManager;
import epson.print.MyPrinter;
import epson.print.Util.EPLog;
import epson.print.inkrpln.InkRplnRepository;
import epson.print.screen.PrintSetting;
import epson.print.service.EpsonService;
import epson.print.service.IEpsonService;
import epson.print.service.IEpsonServiceCallback;
import epson.print.widgets.CustomTitleAlertDialogBuilder;
import epson.print.widgets.LayoutEx;
import epson.print.widgets.LongTapRepeatAdapter;
import java.io.File;

public class SettingScr extends ActivityIACommon implements View.OnClickListener {
    private static final String EXTRA_PRINTER = "myprinter";
    private static final String EXTRA_SIMPLEAP = "simpleap";
    private static final int REQUEST_CODE_INFO = 1;
    private static final int REQUEST_CODE_INK_REPLENISH_PROGRESS = 4;
    private static final int REQUEST_CODE_PAGE_RANGE = 2;
    private static final int REQUEST_CODE_PRINTER = 0;
    public static final String TAG = "PrintSetting";
    private final int COLOR_VALUE_MAX = 50;
    private final int COLOR_VALUE_MIN = -50;
    private final int COPIES_MAX = 30;
    private final int COPIES_MIN = 1;
    private final int EPS_ERR_COMM_ERROR = -1100;
    private final int EPS_ERR_NONE = 0;
    private final int EPS_ERR_OPR_FAIL = -1000;
    private final int EPS_ERR_PRINTER_NOT_SET = EscprError.EPS_ERR_PRINTER_NOT_SET;
    private final int GET_ADVANCED = 64;
    private final int GET_COLOR = 6;
    private final int GET_DUPLEX = 32;
    private final int GET_LAYOUT = 3;
    private final int GET_PAPER_SIZE = 1;
    private final int GET_PAPER_SOURCE = 5;
    private final int GET_PAPER_TYPE = 2;
    private final int GET_QUALITY = 4;
    private final int GET_SUPPORTED_MEDIA = 0;
    private final int PROBE_PRINTER = 17;
    private final int SEARCH_BY_ID = 7;
    private final int SEARCH_ERROR = 16;
    private final int SETTING_DONE = 3;
    private final int SHOW_ERROR_DIALOG = 18;
    private TextView apfStateText;
    /* access modifiers changed from: private */
    public String autoConnectSsid = null;
    /* access modifiers changed from: private */
    public TextView brightness;
    /* access modifiers changed from: private */
    public Button brightnessMinus;
    /* access modifiers changed from: private */
    public Button brightnessPlus;
    /* access modifiers changed from: private */
    public int brightnessValue;
    /* access modifiers changed from: private */
    public int color;
    /* access modifiers changed from: private */
    public TextView colorInfo;
    /* access modifiers changed from: private */
    public int[] color_info = null;
    /* access modifiers changed from: private */
    public TextView contrast;
    /* access modifiers changed from: private */
    public Button contrastMinus;
    /* access modifiers changed from: private */
    public Button contrastPlus;
    /* access modifiers changed from: private */
    public int contrastValue;
    private TextView copies;
    private Button copiesMinus;
    private Button copiesPlus;
    private int copiesValue;
    private boolean disablePrintArea = false;
    /* access modifiers changed from: private */
    public int duplex;
    /* access modifiers changed from: private */
    public TextView duplexInfo;
    /* access modifiers changed from: private */
    public int[] duplex_info = null;
    private boolean enableShowPreview = false;
    /* access modifiers changed from: private */
    public int endValue;
    /* access modifiers changed from: private */
    public int feedDirection;
    /* access modifiers changed from: private */
    public TextView feedDirectionInfo;
    /* access modifiers changed from: private */
    public int[] info = null;
    /* access modifiers changed from: private */
    public boolean isDocumentSetting = true;
    boolean isInfoAvai = false;
    Boolean isNotLoading = true;
    private boolean isRetryAfterConnectSimpleAp = false;
    private boolean isTryConnectSimpleAp = false;
    /* access modifiers changed from: private */
    public int lang = 1;
    /* access modifiers changed from: private */
    public int layout;
    /* access modifiers changed from: private */
    public TextView layoutInfo;
    /* access modifiers changed from: private */
    public int[] layout_info = null;
    /* access modifiers changed from: private */
    public IEpsonServiceCallback mCallback = new IEpsonServiceCallback.Stub() {
        public void onGetInkState() throws RemoteException {
        }

        public void onGetStatusState() throws RemoteException {
        }

        public void onNotifyEndJob(int i) throws RemoteException {
        }

        public void onNotifyProgress(int i, int i2) throws RemoteException {
        }

        public void onFindPrinterResult(String str, String str2, String str3, String str4, String str5) throws RemoteException {
            String unused = SettingScr.this.printerIp = str2;
        }

        public void onNotifyContinueable(int i) throws RemoteException {
            if (!SettingScr.this.mFinishRequested) {
                EPLog.i("IEpsonServiceCallback", "onNotifyContinueable code = " + i);
                if (i == 0) {
                    SettingScr settingScr = SettingScr.this;
                    settingScr.isInfoAvai = true;
                    int unused = settingScr.lang = settingScr.getPrinterLang();
                    SettingScr settingScr2 = SettingScr.this;
                    settingScr2.undoFlag = false;
                    settingScr2.mHandler.sendEmptyMessage(0);
                }
            }
        }

        public void onNotifyError(int i, int i2, boolean z) throws RemoteException {
            if (!SettingScr.this.mFinishRequested) {
                EPLog.i("IEpsonServiceCallback", "onNotifyError errorCode = " + i2);
                SettingScr settingScr = SettingScr.this;
                settingScr.isInfoAvai = true;
                int unused = settingScr.lang = settingScr.getPrinterLang();
                SettingScr settingScr2 = SettingScr.this;
                settingScr2.undoFlag = false;
                settingScr2.mHandler.sendEmptyMessage(0);
            }
        }
    };
    /* access modifiers changed from: private */
    public Context mContext = null;
    private ServiceConnection mEpsonConnection = new ServiceConnection() {
        public void onServiceDisconnected(ComponentName componentName) {
            EPLog.m316v("SettingScr", "onServiceDisconnected");
            try {
                SettingScr.this.mEpsonService.unregisterCallback(SettingScr.this.mCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
            IEpsonService unused = SettingScr.this.mEpsonService = null;
        }

        public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            IEpsonService unused = SettingScr.this.mEpsonService = IEpsonService.Stub.asInterface(iBinder);
            EPLog.m316v("SettingScr", "onServiceConnected");
            if (SettingScr.this.mEpsonService != null) {
                try {
                    SettingScr.this.mEpsonService.registerCallback(SettingScr.this.mCallback);
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
        }
    };
    /* access modifiers changed from: private */
    public IEpsonService mEpsonService = null;
    /* access modifiers changed from: private */
    public volatile boolean mFinishRequested;
    Handler mHandler = new Handler(new Handler.Callback() {
        /* JADX DEBUG: Multi-variable search result rejected for TypeSearchVarInfo{r1v4, resolved type: boolean} */
        /* JADX WARNING: type inference failed for: r1v1 */
        /* JADX WARNING: type inference failed for: r1v5 */
        /* JADX WARNING: type inference failed for: r1v14, types: [int] */
        /* JADX WARNING: type inference failed for: r1v28 */
        /* JADX WARNING: Multi-variable type inference failed */
        /* JADX WARNING: Removed duplicated region for block: B:199:0x0636  */
        /* JADX WARNING: Removed duplicated region for block: B:202:0x0653  */
        /* JADX WARNING: Removed duplicated region for block: B:206:0x0667  */
        /* JADX WARNING: Removed duplicated region for block: B:212:0x0689  */
        /* JADX WARNING: Removed duplicated region for block: B:216:0x06a1 A[LOOP:9: B:214:0x069b->B:216:0x06a1, LOOP_END] */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public boolean handleMessage(android.os.Message r15) {
            /*
                r14 = this;
                java.lang.String r0 = "SettingScr"
                java.lang.String r1 = "handleMessage call setScreenState = false"
                epson.print.Util.EPLog.i(r0, r1)
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r1 = 0
                java.lang.Boolean r2 = java.lang.Boolean.valueOf(r1)
                r0.setScreenState(r2)
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                boolean r0 = r0.mFinishRequested
                r2 = 1
                if (r0 == 0) goto L_0x001b
                return r2
            L_0x001b:
                epson.print.screen.PrintSetting r0 = new epson.print.screen.PrintSetting
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                boolean r4 = r3.isDocumentSetting
                if (r4 == 0) goto L_0x0028
                epson.print.screen.PrintSetting$Kind r4 = epson.print.screen.PrintSetting.Kind.document
                goto L_0x002a
            L_0x0028:
                epson.print.screen.PrintSetting$Kind r4 = epson.print.screen.PrintSetting.Kind.photo
            L_0x002a:
                r0.<init>(r3, r4)
                int r3 = r15.what
                r4 = 64
                r5 = 32
                r6 = 3
                r7 = 0
                r8 = 100
                r10 = 2
                if (r3 == r5) goto L_0x0cba
                if (r3 == r4) goto L_0x0b62
                r4 = 6
                r11 = 5
                r12 = 4
                r13 = 8
                switch(r3) {
                    case 0: goto L_0x0b45;
                    case 1: goto L_0x0996;
                    case 2: goto L_0x06e5;
                    case 3: goto L_0x04c7;
                    case 4: goto L_0x03b6;
                    case 5: goto L_0x0243;
                    case 6: goto L_0x013c;
                    default: goto L_0x0044;
                }
            L_0x0044:
                switch(r3) {
                    case 17: goto L_0x00e7;
                    case 18: goto L_0x0079;
                    default: goto L_0x0047;
                }
            L_0x0047:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "default"
                epson.print.Util.EPLog.i(r15, r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.printerName
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r1 = 2131625174(0x7f0e04d6, float:1.8877549E38)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131231128(0x7f080198, float:1.8078328E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                java.lang.Boolean r0 = java.lang.Boolean.valueOf(r2)
                r15.setScreenState(r0)
                goto L_0x0e25
            L_0x0079:
                int r0 = r15.arg1
                r3 = -1100(0xfffffffffffffbb4, float:NaN)
                if (r0 == r3) goto L_0x00c9
                r3 = -1000(0xfffffffffffffc18, float:NaN)
                if (r0 == r3) goto L_0x00c9
                int r15 = r15.arg1
                java.lang.Integer[] r15 = com.epson.mobilephone.common.escpr.MediaInfo.ErrorTable.getStringId(r15)
                if (r15 != 0) goto L_0x00a5
                java.lang.Integer[] r15 = new java.lang.Integer[r6]
                r0 = 2131624506(0x7f0e023a, float:1.8876194E38)
                java.lang.Integer r0 = java.lang.Integer.valueOf(r0)
                r15[r1] = r0
                r0 = 2131624507(0x7f0e023b, float:1.8876196E38)
                java.lang.Integer r0 = java.lang.Integer.valueOf(r0)
                r15[r2] = r0
                java.lang.Integer r0 = java.lang.Integer.valueOf(r2)
                r15[r10] = r0
            L_0x00a5:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r3 = r15[r2]
                int r3 = r3.intValue()
                java.lang.CharSequence r3 = r0.getText(r3)
                java.lang.String r3 = r3.toString()
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this
                r15 = r15[r1]
                int r15 = r15.intValue()
                java.lang.CharSequence r15 = r4.getText(r15)
                java.lang.String r15 = r15.toString()
                r0.showErrorDialog(r3, r15)
                goto L_0x00e0
            L_0x00c9:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131624778(0x7f0e034a, float:1.8876745E38)
                java.lang.String r15 = r15.getString(r0)
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r1 = 2131624777(0x7f0e0349, float:1.8876743E38)
                java.lang.String r0 = r0.getString(r1)
                epson.print.screen.SettingScr r1 = epson.print.screen.SettingScr.this
                r1.showErrorDialog(r15, r0)
            L_0x00e0:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.resetSettings()
                goto L_0x0e25
            L_0x00e7:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                r0 = 17
                if (r15 == 0) goto L_0x0133
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x012d }
                int r15 = r15.printerLocation     // Catch:{ RemoteException -> 0x012d }
                if (r15 == r10) goto L_0x0124
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x012d }
                epson.print.service.IEpsonService r15 = r15.mEpsonService     // Catch:{ RemoteException -> 0x012d }
                epson.print.screen.SettingScr r1 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x012d }
                java.lang.String r1 = r1.printerId     // Catch:{ RemoteException -> 0x012d }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x012d }
                java.lang.String r3 = r3.printerIp     // Catch:{ RemoteException -> 0x012d }
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x012d }
                int r4 = r4.printerLocation     // Catch:{ RemoteException -> 0x012d }
                if (r4 != r6) goto L_0x0114
                goto L_0x0115
            L_0x0114:
                r10 = 1
            L_0x0115:
                int r15 = r15.searchPrinters(r1, r3, r10)     // Catch:{ RemoteException -> 0x012d }
                if (r15 == 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x012d }
                android.os.Handler r15 = r15.mHandler     // Catch:{ RemoteException -> 0x012d }
                r15.sendEmptyMessageDelayed(r0, r8)     // Catch:{ RemoteException -> 0x012d }
                goto L_0x0e25
            L_0x0124:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x012d }
                android.os.Handler r15 = r15.mHandler     // Catch:{ RemoteException -> 0x012d }
                r15.sendEmptyMessage(r1)     // Catch:{ RemoteException -> 0x012d }
                goto L_0x0e25
            L_0x012d:
                r15 = move-exception
                r15.printStackTrace()
                goto L_0x0e25
            L_0x0133:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r0, r8)
                goto L_0x0e25
            L_0x013c:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x014d
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r4, r8)
                goto L_0x0e25
            L_0x014d:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_COLOR"
                epson.print.Util.EPLog.i(r15, r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] unused = r15.color_info = r7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x018b }
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x018b }
                epson.print.service.IEpsonService r0 = r0.mEpsonService     // Catch:{ RemoteException -> 0x018b }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x018b }
                int r3 = r3.printerLocation     // Catch:{ RemoteException -> 0x018b }
                if (r3 != r10) goto L_0x016b
                r3 = 1
                goto L_0x016c
            L_0x016b:
                r3 = 0
            L_0x016c:
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x018b }
                boolean r4 = r4.isDocumentSetting     // Catch:{ RemoteException -> 0x018b }
                if (r4 == 0) goto L_0x0176
                r4 = 1
                goto L_0x0177
            L_0x0176:
                r4 = 2
            L_0x0177:
                epson.print.screen.SettingScr r6 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x018b }
                int r6 = r6.sizeIndex     // Catch:{ RemoteException -> 0x018b }
                epson.print.screen.SettingScr r7 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x018b }
                int r7 = r7.typeIndex     // Catch:{ RemoteException -> 0x018b }
                int[] r0 = r0.getColor(r3, r4, r6, r7)     // Catch:{ RemoteException -> 0x018b }
                int[] unused = r15.color_info = r0     // Catch:{ RemoteException -> 0x018b }
                goto L_0x0193
            L_0x018b:
                r15 = move-exception
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r0.undoFlag = r2
                r15.printStackTrace()
            L_0x0193:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.color_info
                if (r15 != 0) goto L_0x019f
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.undoFlag = r2
            L_0x019f:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.color_info
                if (r15 == 0) goto L_0x01b0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.color_info
                int r15 = r15.length
                if (r15 > 0) goto L_0x01c7
            L_0x01b0:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = new int[r10]
                int[] unused = r15.color_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.color_info
                r15[r1] = r1
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.color_info
                r15[r2] = r2
            L_0x01c7:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.color_info
                if (r15 == 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.color_info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0e25
                r15 = 0
            L_0x01d9:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.color_info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x01f6
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.color
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.color_info
                r3 = r3[r15]
                if (r0 != r3) goto L_0x01f3
                goto L_0x01f6
            L_0x01f3:
                int r15 = r15 + 1
                goto L_0x01d9
            L_0x01f6:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.color_info
                int r0 = r0.length
                if (r15 < r0) goto L_0x020a
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.color_info
                r0 = r0[r1]
                int unused = r15.color = r0
            L_0x020a:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$Color r0 = new com.epson.mobilephone.common.escpr.MediaInfo$Color
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.colorInfo
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.color
                int r1 = r1.getStringId(r3)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r5)
                goto L_0x0e25
            L_0x0243:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x0254
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r11, r8)
                goto L_0x0e25
            L_0x0254:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_PAPER_SOURCE"
                epson.print.Util.EPLog.i(r15, r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] unused = r15.paper_source_info = r7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                epson.print.service.IEpsonService r0 = r0.mEpsonService     // Catch:{ RemoteException -> 0x02e2 }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                int r3 = r3.sizeIndex     // Catch:{ RemoteException -> 0x02e2 }
                epson.print.screen.SettingScr r5 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                int r5 = r5.typeIndex     // Catch:{ RemoteException -> 0x02e2 }
                epson.print.screen.SettingScr r6 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                int r6 = r6.printerLocation     // Catch:{ RemoteException -> 0x02e2 }
                int[] r0 = r0.getPaperSource(r3, r5, r6)     // Catch:{ RemoteException -> 0x02e2 }
                int[] unused = r15.paper_source_info = r0     // Catch:{ RemoteException -> 0x02e2 }
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                int[] r15 = r15.paper_source_info     // Catch:{ RemoteException -> 0x02e2 }
                if (r15 == 0) goto L_0x02ea
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                boolean r15 = r15.isDocumentSetting     // Catch:{ RemoteException -> 0x02e2 }
                if (r15 == 0) goto L_0x02ea
                java.util.ArrayList r15 = new java.util.ArrayList     // Catch:{ RemoteException -> 0x02e2 }
                r15.<init>()     // Catch:{ RemoteException -> 0x02e2 }
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                int[] r0 = r0.paper_source_info     // Catch:{ RemoteException -> 0x02e2 }
                int r3 = r0.length     // Catch:{ RemoteException -> 0x02e2 }
                r5 = 0
            L_0x029e:
                if (r5 >= r3) goto L_0x02af
                r6 = r0[r5]     // Catch:{ RemoteException -> 0x02e2 }
                if (r6 != r13) goto L_0x02a5
                goto L_0x02ac
            L_0x02a5:
                java.lang.Integer r6 = java.lang.Integer.valueOf(r6)     // Catch:{ RemoteException -> 0x02e2 }
                r15.add(r6)     // Catch:{ RemoteException -> 0x02e2 }
            L_0x02ac:
                int r5 = r5 + 1
                goto L_0x029e
            L_0x02af:
                int r0 = r15.size()     // Catch:{ RemoteException -> 0x02e2 }
                if (r0 <= 0) goto L_0x02dc
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                int r3 = r15.size()     // Catch:{ RemoteException -> 0x02e2 }
                int[] r3 = new int[r3]     // Catch:{ RemoteException -> 0x02e2 }
                int[] unused = r0.paper_source_info = r3     // Catch:{ RemoteException -> 0x02e2 }
                r0 = 0
            L_0x02c1:
                int r3 = r15.size()     // Catch:{ RemoteException -> 0x02e2 }
                if (r0 >= r3) goto L_0x02ea
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                int[] r3 = r3.paper_source_info     // Catch:{ RemoteException -> 0x02e2 }
                java.lang.Object r5 = r15.get(r0)     // Catch:{ RemoteException -> 0x02e2 }
                java.lang.Integer r5 = (java.lang.Integer) r5     // Catch:{ RemoteException -> 0x02e2 }
                int r5 = r5.intValue()     // Catch:{ RemoteException -> 0x02e2 }
                r3[r0] = r5     // Catch:{ RemoteException -> 0x02e2 }
                int r0 = r0 + 1
                goto L_0x02c1
            L_0x02dc:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x02e2 }
                int[] unused = r15.paper_source_info = r7     // Catch:{ RemoteException -> 0x02e2 }
                goto L_0x02ea
            L_0x02e2:
                r15 = move-exception
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r0.undoFlag = r2
                r15.printStackTrace()
            L_0x02ea:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.paper_source_info
                if (r15 != 0) goto L_0x0305
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.undoFlag = r2
                int[] r0 = new int[r2]
                int[] unused = r15.paper_source_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.paper_source_info
                r0 = 128(0x80, float:1.794E-43)
                r15[r1] = r0
            L_0x0305:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.paper_source_info
                if (r15 == 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.paper_source_info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0e25
                r15 = 0
            L_0x0317:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.paper_source_info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x0334
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.paperSource
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.paper_source_info
                r3 = r3[r15]
                if (r0 != r3) goto L_0x0331
                goto L_0x0334
            L_0x0331:
                int r15 = r15 + 1
                goto L_0x0317
            L_0x0334:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.paper_source_info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0348
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.paper_source_info
                r0 = r0[r1]
                int unused = r15.paperSource = r0
            L_0x0348:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int unused = r15.paperSource
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.paper_source_info
                if (r15 == 0) goto L_0x036f
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.paper_source_info
                int r15 = r15.length
                if (r15 > r2) goto L_0x036f
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131231313(0x7f080251, float:1.8078703E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                r15 = 128(0x80, float:1.794E-43)
                goto L_0x0383
            L_0x036f:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131231313(0x7f080251, float:1.8078703E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.paperSource
            L_0x0383:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$PaperSource r1 = new com.epson.mobilephone.common.escpr.MediaInfo$PaperSource
                r1.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r0.mLookupTable = r1
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                android.widget.TextView r0 = r0.paperSourceInfo
                epson.print.screen.SettingScr r1 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r3 = r1.mLookupTable
                int r15 = r3.getStringId(r15)
                java.lang.String r15 = r1.getString(r15)
                r0.setText(r15)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r4)
                goto L_0x0e25
            L_0x03b6:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x03c7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r12, r8)
                goto L_0x0e25
            L_0x03c7:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_QUALITY"
                epson.print.Util.EPLog.i(r15, r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] unused = r15.info = r7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x03ef }
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x03ef }
                epson.print.service.IEpsonService r0 = r0.mEpsonService     // Catch:{ RemoteException -> 0x03ef }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x03ef }
                int r3 = r3.sizeIndex     // Catch:{ RemoteException -> 0x03ef }
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x03ef }
                int r4 = r4.typeIndex     // Catch:{ RemoteException -> 0x03ef }
                int[] r0 = r0.getQuality(r3, r4)     // Catch:{ RemoteException -> 0x03ef }
                int[] unused = r15.info = r0     // Catch:{ RemoteException -> 0x03ef }
                goto L_0x03f7
            L_0x03ef:
                r15 = move-exception
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r0.undoFlag = r2
                r15.printStackTrace()
            L_0x03f7:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x0410
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.undoFlag = r2
                int[] r0 = new int[r2]
                int[] unused = r15.info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                r15[r1] = r10
            L_0x0410:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                if (r15 == 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 > r2) goto L_0x0439
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131231394(0x7f0802a2, float:1.8078868E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                goto L_0x0447
            L_0x0439:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131231394(0x7f0802a2, float:1.8078868E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
            L_0x0447:
                r15 = 0
            L_0x0448:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x0465
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.quality
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                r3 = r3[r15]
                if (r0 != r3) goto L_0x0462
                goto L_0x0465
            L_0x0462:
                int r15 = r15 + 1
                goto L_0x0448
            L_0x0465:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0479
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                r0 = r0[r1]
                int unused = r15.quality = r0
            L_0x0479:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                int r0 = r0.length
                int[] r0 = new int[r0]
                int[] unused = r15.quality_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                int[] unused = r15.quality_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$Quality r0 = new com.epson.mobilephone.common.escpr.MediaInfo$Quality
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.qualityInfo
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.quality
                int r1 = r1.getStringId(r3)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r11)
                goto L_0x0e25
            L_0x04c7:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x04d8
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r6, r8)
                goto L_0x0e25
            L_0x04d8:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_LAYOUT"
                epson.print.Util.EPLog.i(r15, r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] unused = r15.info = r7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x0500 }
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x0500 }
                epson.print.service.IEpsonService r0 = r0.mEpsonService     // Catch:{ RemoteException -> 0x0500 }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x0500 }
                int r3 = r3.sizeIndex     // Catch:{ RemoteException -> 0x0500 }
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x0500 }
                int r4 = r4.typeIndex     // Catch:{ RemoteException -> 0x0500 }
                int[] r0 = r0.getLayout(r3, r4)     // Catch:{ RemoteException -> 0x0500 }
                int[] unused = r15.info = r0     // Catch:{ RemoteException -> 0x0500 }
                goto L_0x0508
            L_0x0500:
                r15 = move-exception
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r0.undoFlag = r2
                r15.printStackTrace()
            L_0x0508:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                boolean r15 = r15.isDocumentSetting
                if (r15 != r2) goto L_0x0520
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = new int[r2]
                int[] unused = r15.info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                r15[r1] = r10
                goto L_0x053c
            L_0x0520:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x053c
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.undoFlag = r2
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x053c
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = new int[r10]
                r0 = {2, 1} // fill-array
                int[] unused = r15.info = r0
            L_0x053c:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = java.util.Arrays.binarySearch(r15, r10)
                if (r15 < 0) goto L_0x05ba
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.printerLocation
                if (r15 == r10) goto L_0x05ba
                java.util.ArrayList r15 = new java.util.ArrayList
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                r15.<init>(r0)
                r0 = 0
            L_0x055d:
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r0 >= r3) goto L_0x0578
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                r3 = r3[r0]
                java.lang.Integer r3 = java.lang.Integer.valueOf(r3)
                r15.add(r3)
                int r0 = r0 + 1
                goto L_0x055d
            L_0x0578:
                r0 = 65536(0x10000, float:9.18355E-41)
                java.lang.Integer r0 = java.lang.Integer.valueOf(r0)
                r15.add(r0)
                r0 = 131072(0x20000, float:1.83671E-40)
                java.lang.Integer r0 = java.lang.Integer.valueOf(r0)
                r15.add(r0)
                r0 = 262144(0x40000, float:3.67342E-40)
                java.lang.Integer r0 = java.lang.Integer.valueOf(r0)
                r15.add(r0)
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r3 = r15.size()
                int[] r3 = new int[r3]
                int[] unused = r0.info = r3
                r0 = 0
            L_0x059f:
                int r3 = r15.size()
                if (r0 >= r3) goto L_0x05ba
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                java.lang.Object r4 = r15.get(r0)
                java.lang.Integer r4 = (java.lang.Integer) r4
                int r4 = r4.intValue()
                r3[r0] = r4
                int r0 = r0 + 1
                goto L_0x059f
            L_0x05ba:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                if (r15 == 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 > r2) goto L_0x05e3
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131231162(0x7f0801ba, float:1.8078397E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                goto L_0x05f1
            L_0x05e3:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131231162(0x7f0801ba, float:1.8078397E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
            L_0x05f1:
                r15 = 0
            L_0x05f2:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x062d
                java.lang.String r0 = "layout info"
                java.lang.StringBuilder r3 = new java.lang.StringBuilder
                r3.<init>()
                java.lang.String r4 = "layout info "
                r3.append(r4)
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this
                int[] r4 = r4.info
                r4 = r4[r15]
                r3.append(r4)
                java.lang.String r3 = r3.toString()
                epson.print.Util.EPLog.m316v(r0, r3)
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.layout
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                r3 = r3[r15]
                if (r0 != r3) goto L_0x062a
                goto L_0x062d
            L_0x062a:
                int r15 = r15 + 1
                goto L_0x05f2
            L_0x062d:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0641
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                r0 = r0[r1]
                int unused = r15.layout = r0
            L_0x0641:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.widgets.LayoutEx r0 = new epson.print.widgets.LayoutEx
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.layout
                if (r15 != r13) goto L_0x0658
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int unused = r15.layout = r10
            L_0x0658:
                java.util.ArrayList r15 = new java.util.ArrayList
                r15.<init>()
                r0 = 0
            L_0x065e:
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r0 >= r3) goto L_0x0683
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                r3 = r3[r0]
                if (r3 == r13) goto L_0x0680
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                r3 = r3[r0]
                java.lang.Integer r3 = java.lang.Integer.valueOf(r3)
                r15.add(r3)
            L_0x0680:
                int r0 = r0 + 1
                goto L_0x065e
            L_0x0683:
                int r0 = r15.size()
                if (r0 != 0) goto L_0x0690
                java.lang.Integer r0 = java.lang.Integer.valueOf(r10)
                r15.add(r0)
            L_0x0690:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r3 = r15.size()
                int[] r3 = new int[r3]
                int[] unused = r0.layout_info = r3
            L_0x069b:
                int r0 = r15.size()
                if (r1 >= r0) goto L_0x06b6
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.layout_info
                java.lang.Object r3 = r15.get(r1)
                java.lang.Integer r3 = (java.lang.Integer) r3
                int r3 = r3.intValue()
                r0[r1] = r3
                int r1 = r1 + 1
                goto L_0x069b
            L_0x06b6:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.layoutInfo
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.layout
                int r1 = r1.getStringId(r3)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r12)
                goto L_0x0e25
            L_0x06e5:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x06f6
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r10, r8)
                goto L_0x0e25
            L_0x06f6:
                java.lang.String r15 = "SettingScr"
                java.lang.String r3 = "GET_PAPER_TYPE"
                epson.print.Util.EPLog.i(r15, r3)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] unused = r15.info = r7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                epson.print.service.IEpsonService r3 = r3.mEpsonService     // Catch:{ RemoteException -> 0x077e }
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                int r4 = r4.sizeIndex     // Catch:{ RemoteException -> 0x077e }
                int[] r3 = r3.getPaperType(r4)     // Catch:{ RemoteException -> 0x077e }
                int[] unused = r15.info = r3     // Catch:{ RemoteException -> 0x077e }
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                int[] r15 = r15.info     // Catch:{ RemoteException -> 0x077e }
                if (r15 == 0) goto L_0x0786
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                boolean r15 = r15.isDocumentSetting     // Catch:{ RemoteException -> 0x077e }
                if (r15 == 0) goto L_0x0786
                java.util.ArrayList r15 = new java.util.ArrayList     // Catch:{ RemoteException -> 0x077e }
                r15.<init>()     // Catch:{ RemoteException -> 0x077e }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                int[] r3 = r3.info     // Catch:{ RemoteException -> 0x077e }
                int r4 = r3.length     // Catch:{ RemoteException -> 0x077e }
                r5 = 0
            L_0x0734:
                if (r5 >= r4) goto L_0x074b
                r8 = r3[r5]     // Catch:{ RemoteException -> 0x077e }
                r9 = 91
                if (r8 < r9) goto L_0x0741
                r9 = 93
                if (r8 > r9) goto L_0x0741
                goto L_0x0748
            L_0x0741:
                java.lang.Integer r8 = java.lang.Integer.valueOf(r8)     // Catch:{ RemoteException -> 0x077e }
                r15.add(r8)     // Catch:{ RemoteException -> 0x077e }
            L_0x0748:
                int r5 = r5 + 1
                goto L_0x0734
            L_0x074b:
                int r3 = r15.size()     // Catch:{ RemoteException -> 0x077e }
                if (r3 <= 0) goto L_0x0778
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                int r4 = r15.size()     // Catch:{ RemoteException -> 0x077e }
                int[] r4 = new int[r4]     // Catch:{ RemoteException -> 0x077e }
                int[] unused = r3.info = r4     // Catch:{ RemoteException -> 0x077e }
                r3 = 0
            L_0x075d:
                int r4 = r15.size()     // Catch:{ RemoteException -> 0x077e }
                if (r3 >= r4) goto L_0x0786
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                int[] r4 = r4.info     // Catch:{ RemoteException -> 0x077e }
                java.lang.Object r5 = r15.get(r3)     // Catch:{ RemoteException -> 0x077e }
                java.lang.Integer r5 = (java.lang.Integer) r5     // Catch:{ RemoteException -> 0x077e }
                int r5 = r5.intValue()     // Catch:{ RemoteException -> 0x077e }
                r4[r3] = r5     // Catch:{ RemoteException -> 0x077e }
                int r3 = r3 + 1
                goto L_0x075d
            L_0x0778:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x077e }
                int[] unused = r15.info = r7     // Catch:{ RemoteException -> 0x077e }
                goto L_0x0786
            L_0x077e:
                r15 = move-exception
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                r3.undoFlag = r2
                r15.printStackTrace()
            L_0x0786:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x07af
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.undoFlag = r2
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x07af
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r3 = new int[r10]
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_PLAIN
                int r4 = r4.getCode()
                r3[r1] = r4
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_PGPHOTO
                int r4 = r4.getCode()
                r3[r2] = r4
                int[] unused = r15.info = r3
            L_0x07af:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                if (r15 == 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 > r2) goto L_0x07d8
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r3 = 2131231316(0x7f080254, float:1.807871E38)
                android.view.View r15 = r15.findViewById(r3)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                goto L_0x07e6
            L_0x07d8:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r3 = 2131231316(0x7f080254, float:1.807871E38)
                android.view.View r15 = r15.findViewById(r3)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
            L_0x07e6:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int unused = r15.typeIndex = r1
            L_0x07eb:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.typeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r15 >= r3) goto L_0x0817
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.paperType
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this
                int r4 = r4.typeIndex
                r3 = r3[r4]
                if (r15 != r3) goto L_0x0811
                goto L_0x0817
            L_0x0811:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.screen.SettingScr.access$1708(r15)
                goto L_0x07eb
            L_0x0817:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.typeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r15 < r3) goto L_0x085a
                int r15 = r0.getDefaultPaperType()
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.typeIndex = r1
            L_0x082f:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.typeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r0 >= r3) goto L_0x085a
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.typeIndex
                r0 = r0[r3]
                if (r15 != r0) goto L_0x0854
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.paperType = r15
                goto L_0x085a
            L_0x0854:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                epson.print.screen.SettingScr.access$1708(r0)
                goto L_0x082f
            L_0x085a:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.typeIndex
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0923
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                boolean r15 = r15.isDocumentSetting
                if (r15 != 0) goto L_0x08a8
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r15 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_MATTE
                int r15 = r15.getCode()
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.typeIndex = r1
            L_0x087c:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.typeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r0 >= r3) goto L_0x0923
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.typeIndex
                r0 = r0[r3]
                if (r15 != r0) goto L_0x08a2
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.paperType = r15
                goto L_0x0923
            L_0x08a2:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                epson.print.screen.SettingScr.access$1708(r0)
                goto L_0x087c
            L_0x08a8:
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r15 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_PLAIN1
                int r15 = r15.getCode()
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.typeIndex = r1
            L_0x08b3:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.typeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r0 >= r3) goto L_0x08de
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.typeIndex
                r0 = r0[r3]
                if (r15 != r0) goto L_0x08d8
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.paperType = r15
                goto L_0x08de
            L_0x08d8:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                epson.print.screen.SettingScr.access$1708(r0)
                goto L_0x08b3
            L_0x08de:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.typeIndex
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0923
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r15 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_AUTO_PLAIN
                int r15 = r15.getCode()
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.typeIndex = r1
            L_0x08f8:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.typeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r0 >= r3) goto L_0x0923
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.typeIndex
                r0 = r0[r3]
                if (r15 != r0) goto L_0x091d
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.paperType = r15
                goto L_0x0923
            L_0x091d:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                epson.print.screen.SettingScr.access$1708(r0)
                goto L_0x08f8
            L_0x0923:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.typeIndex
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0948
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int unused = r15.typeIndex = r1
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                epson.print.screen.SettingScr r1 = epson.print.screen.SettingScr.this
                int r1 = r1.typeIndex
                r0 = r0[r1]
                int unused = r15.paperType = r0
            L_0x0948:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                int r0 = r0.length
                int[] r0 = new int[r0]
                int[] unused = r15.paper_type_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                int[] unused = r15.paper_type_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$PaperType r0 = new com.epson.mobilephone.common.escpr.MediaInfo$PaperType
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.paperTypeInfo
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.paperType
                int r1 = r1.getStringId(r3)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r6)
                goto L_0x0e25
            L_0x0996:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x09a7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r2, r8)
                goto L_0x0e25
            L_0x09a7:
                java.lang.String r15 = "SettingScr"
                java.lang.String r3 = "GET_PAPER_SIZE"
                epson.print.Util.EPLog.i(r15, r3)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] unused = r15.info = r7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x09c3 }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x09c3 }
                epson.print.service.IEpsonService r3 = r3.mEpsonService     // Catch:{ RemoteException -> 0x09c3 }
                int[] r3 = r3.getPaperSize()     // Catch:{ RemoteException -> 0x09c3 }
                int[] unused = r15.info = r3     // Catch:{ RemoteException -> 0x09c3 }
                goto L_0x09cb
            L_0x09c3:
                r15 = move-exception
                r15.printStackTrace()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.undoFlag = r2
            L_0x09cb:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x0a27
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.undoFlag = r2
                r3 = 9
                int[] r3 = new int[r3]
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r5 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_A4
                int r5 = r5.getCode()
                r3[r1] = r5
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r5 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_A3
                int r5 = r5.getCode()
                r3[r2] = r5
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r5 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_B4
                int r5 = r5.getCode()
                r3[r10] = r5
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r5 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_B5
                int r5 = r5.getCode()
                r3[r6] = r5
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r5 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_LETTER
                int r5 = r5.getCode()
                r3[r12] = r5
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r5 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_LEGAL
                int r5 = r5.getCode()
                r3[r11] = r5
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r5 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_POSTCARD
                int r5 = r5.getCode()
                r3[r4] = r5
                r4 = 7
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r5 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_4X6
                int r5 = r5.getCode()
                r3[r4] = r5
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_L
                int r4 = r4.getCode()
                r3[r13] = r4
                int[] unused = r15.info = r3
            L_0x0a27:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                if (r15 == 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0e25
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 > r2) goto L_0x0a50
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r3 = 2131231309(0x7f08024d, float:1.8078695E38)
                android.view.View r15 = r15.findViewById(r3)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                goto L_0x0a5e
            L_0x0a50:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r3 = 2131231309(0x7f08024d, float:1.8078695E38)
                android.view.View r15 = r15.findViewById(r3)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
            L_0x0a5e:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int unused = r15.sizeIndex = r1
            L_0x0a63:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.sizeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r15 >= r3) goto L_0x0a8f
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.paperSize
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this
                int r4 = r4.sizeIndex
                r3 = r3[r4]
                if (r15 != r3) goto L_0x0a89
                goto L_0x0a8f
            L_0x0a89:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.screen.SettingScr.access$1208(r15)
                goto L_0x0a63
            L_0x0a8f:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.sizeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r15 < r3) goto L_0x0ad2
                int r15 = r0.getDefaultPaperSize()
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.sizeIndex = r1
            L_0x0aa7:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.sizeIndex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.info
                int r3 = r3.length
                if (r0 >= r3) goto L_0x0ad2
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.sizeIndex
                r0 = r0[r3]
                if (r15 != r0) goto L_0x0acc
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int unused = r0.paperSize = r15
                goto L_0x0ad2
            L_0x0acc:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                epson.print.screen.SettingScr.access$1208(r0)
                goto L_0x0aa7
            L_0x0ad2:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int r15 = r15.sizeIndex
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0af7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int unused = r15.sizeIndex = r1
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                epson.print.screen.SettingScr r1 = epson.print.screen.SettingScr.this
                int r1 = r1.sizeIndex
                r0 = r0[r1]
                int unused = r15.paperSize = r0
            L_0x0af7:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                int r0 = r0.length
                int[] r0 = new int[r0]
                int[] unused = r15.paper_size_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.info
                int[] unused = r15.paper_size_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$PaperSize r0 = new com.epson.mobilephone.common.escpr.MediaInfo$PaperSize
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.paperSizeInfo
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.paperSize
                int r1 = r1.getStringId(r3)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r10)
                goto L_0x0e25
            L_0x0b45:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 == 0) goto L_0x0b59
                epson.print.screen.SettingScr$3$1 r15 = new epson.print.screen.SettingScr$3$1
                r15.<init>()
                java.lang.Void[] r0 = new java.lang.Void[r1]
                r15.execute(r0)
                goto L_0x0e25
            L_0x0b59:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r1, r8)
                goto L_0x0e25
            L_0x0b62:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r0 = 2131231301(0x7f080245, float:1.807868E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.TextView r15 = (android.widget.TextView) r15
                java.lang.StringBuilder r0 = new java.lang.StringBuilder
                r0.<init>()
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.startValue
                r0.append(r3)
                java.lang.String r3 = ".."
                r0.append(r3)
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.endValue
                r0.append(r3)
                java.lang.String r0 = r0.toString()
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$FeedDirection r0 = new com.epson.mobilephone.common.escpr.MediaInfo$FeedDirection
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.feedDirectionInfo
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r3 = r0.mLookupTable
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this
                int r4 = r4.feedDirection
                int r3 = r3.getStringId(r4)
                java.lang.String r0 = r0.getString(r3)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$PrintDate r0 = new com.epson.mobilephone.common.escpr.MediaInfo$PrintDate
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.printDateInfo
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r3 = r0.mLookupTable
                epson.print.screen.SettingScr r4 = epson.print.screen.SettingScr.this
                int r4 = r4.printdate
                int r3 = r3.getStringId(r4)
                java.lang.String r0 = r0.getString(r3)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.brightness
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.brightnessValue
                java.lang.String r0 = java.lang.String.valueOf(r0)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.Button r15 = r15.brightnessMinus
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.brightnessValue
                r3 = -50
                if (r0 == r3) goto L_0x0c15
                r0 = 1
                goto L_0x0c16
            L_0x0c15:
                r0 = 0
            L_0x0c16:
                r15.setEnabled(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.Button r15 = r15.brightnessPlus
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.brightnessValue
                r4 = 50
                if (r0 == r4) goto L_0x0c2b
                r0 = 1
                goto L_0x0c2c
            L_0x0c2b:
                r0 = 0
            L_0x0c2c:
                r15.setEnabled(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.contrast
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.contrastValue
                java.lang.String r0 = java.lang.String.valueOf(r0)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.Button r15 = r15.contrastMinus
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.contrastValue
                if (r0 == r3) goto L_0x0c52
                r0 = 1
                goto L_0x0c53
            L_0x0c52:
                r0 = 0
            L_0x0c53:
                r15.setEnabled(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.Button r15 = r15.contrastPlus
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.contrastValue
                if (r0 == r4) goto L_0x0c66
                r0 = 1
                goto L_0x0c67
            L_0x0c66:
                r0 = 0
            L_0x0c67:
                r15.setEnabled(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.saturation
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.saturationValue
                java.lang.String r0 = java.lang.String.valueOf(r0)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.Button r15 = r15.saturationMinus
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.saturationValue
                if (r0 == r3) goto L_0x0c8d
                r0 = 1
                goto L_0x0c8e
            L_0x0c8d:
                r0 = 0
            L_0x0c8e:
                r15.setEnabled(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.Button r15 = r15.saturationPlus
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.saturationValue
                if (r0 == r4) goto L_0x0ca0
                r1 = 1
            L_0x0ca0:
                r15.setEnabled(r1)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                r15.updateSettingView()
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                java.lang.Boolean r0 = java.lang.Boolean.valueOf(r2)
                r15.setScreenState(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                boolean r0 = r15.undoFlag
                boolean unused = r15.updateSupportedMediaFile(r0)
                goto L_0x0e25
            L_0x0cba:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x0ccb
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r5, r8)
                goto L_0x0e25
            L_0x0ccb:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_DUPLEX"
                epson.print.Util.EPLog.i(r15, r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] unused = r15.duplex_info = r7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x0cee }
                epson.print.service.IEpsonService r15 = r15.mEpsonService     // Catch:{ RemoteException -> 0x0cee }
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x0cee }
                int r0 = r0.sizeIndex     // Catch:{ RemoteException -> 0x0cee }
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this     // Catch:{ RemoteException -> 0x0cee }
                int r3 = r3.typeIndex     // Catch:{ RemoteException -> 0x0cee }
                int r15 = r15.getDuplex(r0, r3)     // Catch:{ RemoteException -> 0x0cee }
                goto L_0x0cf7
            L_0x0cee:
                r15 = move-exception
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                r0.undoFlag = r2
                r15.printStackTrace()
                r15 = 0
            L_0x0cf7:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                java.lang.String r0 = r0.printerId
                if (r0 != 0) goto L_0x0d2e
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.paperType
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r3 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_PLAIN
                int r3 = r3.getCode()
                if (r0 != r3) goto L_0x0d2e
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = new int[r6]
                int[] unused = r15.duplex_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r2] = r2
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r10] = r10
                goto L_0x0da4
            L_0x0d2e:
                if (r15 == 0) goto L_0x0d95
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.paperSource
                r3 = 16
                if (r0 == r3) goto L_0x0d95
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.layout
                if (r0 != r2) goto L_0x0d75
                r15 = r15 & r10
                if (r15 == 0) goto L_0x0d65
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = new int[r6]
                int[] unused = r15.duplex_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r2] = r2
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r10] = r10
                goto L_0x0da4
            L_0x0d65:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = new int[r2]
                int[] unused = r15.duplex_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
                goto L_0x0da4
            L_0x0d75:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = new int[r6]
                int[] unused = r15.duplex_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r2] = r2
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r10] = r10
                goto L_0x0da4
            L_0x0d95:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = new int[r2]
                int[] unused = r15.duplex_info = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
            L_0x0da4:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                if (r15 == 0) goto L_0x0e17
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r15 = r15.duplex_info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0e17
                r15 = 0
            L_0x0db6:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.duplex_info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x0dd3
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int r0 = r0.duplex
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int[] r3 = r3.duplex_info
                r3 = r3[r15]
                if (r0 != r3) goto L_0x0dd0
                goto L_0x0dd3
            L_0x0dd0:
                int r15 = r15 + 1
                goto L_0x0db6
            L_0x0dd3:
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                int[] r0 = r0.duplex_info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0de7
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                int[] r0 = r15.duplex_info
                r0 = r0[r1]
                int unused = r15.duplex = r0
            L_0x0de7:
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$Duplex r0 = new com.epson.mobilephone.common.escpr.MediaInfo$Duplex
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.widget.TextView r15 = r15.duplexInfo
                epson.print.screen.SettingScr r0 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                epson.print.screen.SettingScr r3 = epson.print.screen.SettingScr.this
                int r3 = r3.duplex
                int r1 = r1.getStringId(r3)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
            L_0x0e17:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "get Color setScreenState = true"
                epson.print.Util.EPLog.i(r15, r0)
                epson.print.screen.SettingScr r15 = epson.print.screen.SettingScr.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r4)
            L_0x0e25:
                return r2
            */
            throw new UnsupportedOperationException("Method not decompiled: epson.print.screen.SettingScr.C23643.handleMessage(android.os.Message):boolean");
        }
    });
    /* access modifiers changed from: private */
    public MediaInfo.AbstractInfo mLookupTable;
    private MediaInfo.AbstractInfo mPaperSizeType;
    private boolean mPrinterSelectDone;
    private int mSharpnessValue;
    private TextView mSharpnessValueText;
    private boolean mWaiteInkReplenProgress;
    /* access modifiers changed from: private */
    public int paperSize;
    /* access modifiers changed from: private */
    public TextView paperSizeInfo;
    /* access modifiers changed from: private */
    public int paperSource;
    /* access modifiers changed from: private */
    public TextView paperSourceInfo;
    /* access modifiers changed from: private */
    public int paperType;
    /* access modifiers changed from: private */
    public TextView paperTypeInfo;
    /* access modifiers changed from: private */
    public int[] paper_size_info = null;
    /* access modifiers changed from: private */
    public int[] paper_source_info = null;
    /* access modifiers changed from: private */
    public int[] paper_type_info = null;
    private int photoApfValueForLocalPrinter;
    private boolean printAll;
    /* access modifiers changed from: private */
    public TextView printDateInfo;
    /* access modifiers changed from: private */
    public int printdate;
    private MyPrinter printer = null;
    private String printerDeviceId;
    /* access modifiers changed from: private */
    public String printerEmailAddress;
    /* access modifiers changed from: private */
    public String printerId;
    /* access modifiers changed from: private */
    public String printerIp;
    /* access modifiers changed from: private */
    public int printerLocation;
    /* access modifiers changed from: private */
    public TextView printerName;
    private String printerSerialNo;
    private View progressGetOption;
    /* access modifiers changed from: private */
    public int quality;
    /* access modifiers changed from: private */
    public TextView qualityInfo;
    /* access modifiers changed from: private */
    public int[] quality_info = null;
    /* access modifiers changed from: private */
    public TextView saturation;
    /* access modifiers changed from: private */
    public Button saturationMinus;
    /* access modifiers changed from: private */
    public Button saturationPlus;
    /* access modifiers changed from: private */
    public int saturationValue;
    private int sheets = 1;
    /* access modifiers changed from: private */
    public int sizeIndex = 0;
    /* access modifiers changed from: private */
    public int startValue;
    /* access modifiers changed from: private */
    public int typeIndex = 0;
    boolean undoFlag = true;

    static /* synthetic */ int access$1208(SettingScr settingScr) {
        int i = settingScr.sizeIndex;
        settingScr.sizeIndex = i + 1;
        return i;
    }

    static /* synthetic */ int access$1708(SettingScr settingScr) {
        int i = settingScr.typeIndex;
        settingScr.typeIndex = i + 1;
        return i;
    }

    /* access modifiers changed from: protected */
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        setContentView((int) R.layout.setting_layout);
        setActionBar((int) R.string.str_btn_printer_settings, true);
        bindEpsonService();
        this.mContext = this;
        this.isDocumentSetting = getIntent().getBooleanExtra(PrintProgress.PARAM_DOCUMENT_MODE, false);
        if (this.isDocumentSetting) {
            this.sheets = getIntent().getIntExtra("SHEETS", 1);
            this.disablePrintArea = getIntent().getBooleanExtra("PRINTAREA", false);
        }
        this.printerName = (TextView) findViewById(R.id.printer_name);
        this.paperSizeInfo = (TextView) findViewById(R.id.paper_size_info);
        this.paperTypeInfo = (TextView) findViewById(R.id.paper_type_info);
        this.layoutInfo = (TextView) findViewById(R.id.layout_info);
        this.qualityInfo = (TextView) findViewById(R.id.quality_info);
        this.paperSourceInfo = (TextView) findViewById(R.id.paper_source_info);
        this.copies = (TextView) findViewById(R.id.copies);
        this.copiesMinus = (Button) findViewById(R.id.copies_minus_button);
        this.copiesPlus = (Button) findViewById(R.id.copies_plus_button);
        LongTapRepeatAdapter.bless(this.copiesMinus);
        LongTapRepeatAdapter.bless(this.copiesPlus);
        this.colorInfo = (TextView) findViewById(R.id.color_info);
        this.duplexInfo = (TextView) findViewById(R.id.duplex_info);
        this.feedDirectionInfo = (TextView) findViewById(R.id.feed_direction_info);
        this.printDateInfo = (TextView) findViewById(R.id.printdate_info);
        this.apfStateText = (TextView) findViewById(R.id.apf_setting_text);
        this.mSharpnessValueText = (TextView) findViewById(R.id.sharpness_setting_text);
        this.brightness = (TextView) findViewById(R.id.brightness);
        this.brightnessMinus = (Button) findViewById(R.id.brightness_minus_button);
        this.brightnessPlus = (Button) findViewById(R.id.brightness_plus_button);
        this.contrast = (TextView) findViewById(R.id.contrast);
        this.contrastMinus = (Button) findViewById(R.id.contrast_minus_button);
        this.contrastPlus = (Button) findViewById(R.id.contrast_plus_button);
        this.saturation = (TextView) findViewById(R.id.saturation);
        this.saturationMinus = (Button) findViewById(R.id.saturation_minus_button);
        this.saturationPlus = (Button) findViewById(R.id.saturation_plus_button);
        this.progressGetOption = findViewById(R.id.progressGetOption);
        this.enableShowPreview = getSharedPreferences(Constants.PREFS_EPSON_CONNECT, 0).getBoolean(Constants.ENABLE_SHOW_PREVIEW, true);
        loadConfig();
        setClickListener();
        updatePrinterIcon();
        if (this.printerId != null) {
            this.undoFlag = false;
            if (loadSupportedMediaFile()) {
                this.mHandler.sendEmptyMessage(1);
            } else {
                this.mHandler.sendEmptyMessage(17);
            }
        } else {
            this.mHandler.sendEmptyMessage(1);
        }
    }

    private void updatePrinterIcon() {
        if (this.printerName.getText().equals(getString(R.string.str_lbl_title_scan))) {
            ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setVisibility(8);
            return;
        }
        ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setVisibility(0);
        switch (this.printerLocation) {
            case 1:
                ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setImageResource(R.C2136drawable.print_local);
                return;
            case 2:
                ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setImageResource(R.C2136drawable.print_remote);
                return;
            case 3:
                ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setImageResource(R.C2136drawable.print_ip);
                return;
            default:
                return;
        }
    }

    private void setClickListener() {
        this.copiesMinus.setOnClickListener(this);
        this.copiesPlus.setOnClickListener(this);
        this.brightnessMinus.setOnClickListener(this);
        this.brightnessPlus.setOnClickListener(this);
        this.contrastMinus.setOnClickListener(this);
        this.contrastPlus.setOnClickListener(this);
        this.saturationMinus.setOnClickListener(this);
        this.saturationPlus.setOnClickListener(this);
        if (this.isDocumentSetting) {
            findViewById(R.id.page_range_setting).setOnClickListener(this);
        }
        findViewById(R.id.printer).setOnClickListener(this);
        findViewById(R.id.paper_size).setOnClickListener(this);
        findViewById(R.id.paper_type).setOnClickListener(this);
        findViewById(R.id.layout).setOnClickListener(this);
        findViewById(R.id.quality).setOnClickListener(this);
        findViewById(R.id.paper_source).setOnClickListener(this);
        findViewById(R.id.color).setOnClickListener(this);
        findViewById(R.id.duplex).setOnClickListener(this);
        findViewById(R.id.feed_direction).setOnClickListener(this);
        findViewById(R.id.printdate).setOnClickListener(this);
        findViewById(R.id.apf_setting_layout).setOnClickListener(this);
        findViewById(R.id.sharpness_setting_layout).setOnClickListener(this);
    }

    private void loadConfig() {
        MyPrinter curPrinter = MyPrinter.getCurPrinter(this);
        if (curPrinter == null || curPrinter.getName() == null) {
            this.printerName.setText(getString(R.string.str_lbl_title_scan));
        } else {
            this.printerName.setText(curPrinter.getUserDefName(this));
        }
        this.printerDeviceId = curPrinter.getName();
        this.printerId = curPrinter.getPrinterId();
        this.printerIp = curPrinter.getIp();
        this.printerSerialNo = curPrinter.getSerialNo();
        this.printerEmailAddress = curPrinter.getEmailAddress();
        this.printerLocation = curPrinter.getLocation();
        boolean z = true;
        if (this.printerLocation == 0) {
            this.printerLocation = 1;
        }
        this.autoConnectSsid = WiFiDirectManager.getConnectInfo(this, WiFiDirectManager.DEVICE_TYPE_PRINTER);
        PrintSetting printSetting = new PrintSetting(this, this.isDocumentSetting ? PrintSetting.Kind.document : PrintSetting.Kind.photo);
        printSetting.loadSettings();
        this.mLookupTable = new MediaInfo.PaperSize();
        this.paperSize = printSetting.paperSizeValue;
        this.paperSizeInfo.setText(getString(this.mLookupTable.getStringId(this.paperSize)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.PaperType();
        this.paperType = printSetting.paperTypeValue;
        this.paperTypeInfo.setText(getString(this.mLookupTable.getStringId(this.paperType)));
        this.mLookupTable.destructor();
        this.mPaperSizeType = printSetting.loadPaperSizeTypePear();
        this.mPaperSizeType.putID(this.paperSize, this.paperType);
        this.mLookupTable = new LayoutEx();
        int i = printSetting.layoutMultiPageValue;
        if (i != 0) {
            this.layout = i;
        } else {
            this.layout = printSetting.layoutValue;
        }
        this.layoutInfo.setText(getString(this.mLookupTable.getStringId(this.layout)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.Quality();
        this.quality = printSetting.qualityValue;
        this.qualityInfo.setText(getString(this.mLookupTable.getStringId(this.quality)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.PaperSource();
        this.paperSource = printSetting.paperSourceValue;
        this.paperSourceInfo.setText(getString(this.mLookupTable.getStringId(this.paperSource)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.Color();
        this.color = printSetting.colorValue;
        this.colorInfo.setText(getString(this.mLookupTable.getStringId(this.color)));
        this.mLookupTable.destructor();
        this.copiesValue = printSetting.copiesValue;
        this.copies.setText(String.valueOf(this.copiesValue));
        this.copiesMinus.setEnabled(this.copiesValue != 1);
        Button button = this.copiesPlus;
        if (this.copiesValue == 30) {
            z = false;
        }
        button.setEnabled(z);
        this.brightnessValue = printSetting.brightnessValue;
        this.contrastValue = printSetting.contrastValue;
        this.saturationValue = printSetting.saturationValue;
        this.mLookupTable = new MediaInfo.Duplex();
        this.duplex = printSetting.duplexValue;
        this.duplexInfo.setText(getString(this.mLookupTable.getStringId(this.duplex)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.FeedDirection();
        this.feedDirection = printSetting.feedDirectionValue;
        this.feedDirectionInfo.setText(getString(this.mLookupTable.getStringId(this.feedDirection)));
        this.mLookupTable.destructor();
        this.lang = curPrinter.getLang();
        if (this.isDocumentSetting) {
            this.printAll = printSetting.printAll;
            this.startValue = printSetting.startValue;
            this.endValue = printSetting.endValue;
            ((TextView) findViewById(R.id.page_range_value)).setText(this.startValue + ".." + this.endValue);
            return;
        }
        this.mLookupTable = new MediaInfo.PrintDate();
        this.printdate = printSetting.printdate;
        this.printDateInfo.setText(getString(this.mLookupTable.getStringId(this.printdate)));
        this.mLookupTable.destructor();
        this.photoApfValueForLocalPrinter = printSetting.photoApfValueForLocalPrinter;
        displayApfState(this.photoApfValueForLocalPrinter);
        this.mSharpnessValue = printSetting.sharpnessForPhoto;
        displaySharpnessState(this.mSharpnessValue);
    }

    private void displayApfState(int i) {
        MediaInfo.ApfState apfState = new MediaInfo.ApfState();
        this.apfStateText.setText(apfState.getStringId(i));
        apfState.destructor();
    }

    private void displaySharpnessState(int i) {
        MediaInfo.SharpnessState sharpnessState = new MediaInfo.SharpnessState();
        this.mSharpnessValueText.setText(sharpnessState.getStringId(i));
        sharpnessState.destructor();
    }

    private boolean loadSupportedMediaFile() {
        ExternalFileUtils instance = ExternalFileUtils.getInstance(this);
        File savedSupportedMedia = instance.getSavedSupportedMedia();
        File supportedMedia = instance.getSupportedMedia();
        File preSupportedMedia = instance.getPreSupportedMedia();
        EPLog.i("PrintSetting", "call loadSupportedMedia");
        try {
            if (!savedSupportedMedia.exists()) {
                EPLog.w("loadSupportedMedia", savedSupportedMedia.getName() + " not exist");
                return false;
            }
            Utils.copyFile(savedSupportedMedia, supportedMedia);
            Utils.copyFile(savedSupportedMedia, preSupportedMedia);
            File savedAreaInfo = instance.getSavedAreaInfo();
            File areaInfo = instance.getAreaInfo();
            File preAreaInfo = instance.getPreAreaInfo();
            try {
                if (!savedAreaInfo.exists()) {
                    return true;
                }
                Utils.copyFile(savedAreaInfo, areaInfo);
                Utils.copyFile(savedAreaInfo, preAreaInfo);
                return true;
            } catch (Exception e) {
                EPLog.w("loadSupportedMedia", "failure " + e.getMessage());
                return false;
            }
        } catch (Exception e2) {
            EPLog.w("loadSupportedMedia", "failure " + e2.getMessage());
            return false;
        }
    }

    /* access modifiers changed from: private */
    public boolean updateSupportedMediaFile(boolean z) {
        ExternalFileUtils instance = ExternalFileUtils.getInstance(this);
        EPLog.i("PrintSetting", "call updateSupportedMedia");
        File supportedMedia = instance.getSupportedMedia();
        File preSupportedMedia = instance.getPreSupportedMedia();
        if (z) {
            File file = preSupportedMedia;
            preSupportedMedia = supportedMedia;
            supportedMedia = file;
        }
        try {
            Utils.copyFile(supportedMedia, preSupportedMedia);
            File areaInfo = instance.getAreaInfo();
            File preAreaInfo = instance.getPreAreaInfo();
            if (!z) {
                File file2 = areaInfo;
                areaInfo = preAreaInfo;
                preAreaInfo = file2;
            }
            try {
                if (!preAreaInfo.exists()) {
                    return true;
                }
                Utils.copyFile(preAreaInfo, areaInfo);
                return true;
            } catch (Exception e) {
                if (preAreaInfo != null && preAreaInfo.exists()) {
                    preAreaInfo.delete();
                }
                if (areaInfo != null && areaInfo.exists()) {
                    areaInfo.delete();
                }
                EPLog.w("updateSupportedMediaFile", "failure " + e.getMessage());
                return false;
            }
        } catch (Exception e2) {
            if (supportedMedia != null && supportedMedia.exists()) {
                supportedMedia.delete();
            }
            if (preSupportedMedia != null && preSupportedMedia.exists()) {
                preSupportedMedia.delete();
            }
            EPLog.w("updateSupportedMediaFile", "failure " + e2.getMessage());
            return false;
        }
    }

    private boolean saveSupportedMediaFile() {
        ExternalFileUtils instance = ExternalFileUtils.getInstance(this);
        EPLog.i("PrintSetting", "call saveSupportedMedia");
        File supportedMedia = instance.getSupportedMedia();
        File savedSupportedMedia = instance.getSavedSupportedMedia();
        try {
            if (!supportedMedia.exists()) {
                EPLog.w("updateSupportedMediaFile", supportedMedia.getName() + " not exist");
                return false;
            }
            Utils.copyFile(supportedMedia, savedSupportedMedia);
            File areaInfo = instance.getAreaInfo();
            File savedAreaInfo = instance.getSavedAreaInfo();
            int i = this.printerLocation;
            if (i == 1 || i == 3) {
                try {
                    if (!areaInfo.exists()) {
                        EPLog.w("updateSupportedMediaFile", areaInfo.getName() + " not exist");
                        return false;
                    }
                    Utils.copyFile(areaInfo, savedAreaInfo);
                } catch (Exception e) {
                    EPLog.w("saveSupportedMediaFile", "failure " + e.getMessage());
                    return false;
                }
            } else {
                EPLog.i("PrintSetting", "delete AreaInfo");
                instance.removeAreaInfo();
            }
            return true;
        } catch (Exception e2) {
            EPLog.w("saveSupportedMediaFile", "failure " + e2.getMessage());
            return false;
        }
    }

    private void saveChanged() {
        SharedPreferences.Editor edit = getSharedPreferences("PrintSetting", 0).edit();
        edit.putInt(Constants.PREFS_INFO_PRINT_SAVE, 1);
        edit.commit();
        MyPrinter myPrinter = new MyPrinter(this.printerDeviceId, this.printerIp, this.printerId, this.printerSerialNo, this.printerEmailAddress, this.printerLocation);
        myPrinter.setLang(this.lang);
        myPrinter.setCurPrinter(this);
        PrintSetting printSetting = new PrintSetting(this, this.isDocumentSetting ? PrintSetting.Kind.document : PrintSetting.Kind.photo);
        printSetting.paperSizeValue = this.paperSize;
        printSetting.paperTypeValue = this.paperType;
        int i = this.layout;
        if ((-65536 & i) != 0) {
            printSetting.layoutValue = 2;
            printSetting.layoutMultiPageValue = i;
        } else {
            printSetting.layoutValue = i;
            printSetting.layoutMultiPageValue = 0;
        }
        printSetting.qualityValue = this.quality;
        printSetting.paperSourceValue = this.paperSource;
        printSetting.colorValue = this.color;
        printSetting.duplexValue = this.duplex;
        printSetting.feedDirectionValue = this.feedDirection;
        printSetting.copiesValue = this.copiesValue;
        printSetting.brightnessValue = this.brightnessValue;
        printSetting.contrastValue = this.contrastValue;
        printSetting.saturationValue = this.saturationValue;
        if (this.isDocumentSetting) {
            printSetting.printAll = this.printAll;
            printSetting.startValue = this.startValue;
            printSetting.endValue = this.endValue;
        } else {
            printSetting.printdate = this.printdate;
            printSetting.photoApfValueForLocalPrinter = this.photoApfValueForLocalPrinter;
            printSetting.sharpnessForPhoto = this.mSharpnessValue;
        }
        printSetting.saveSettings();
        printSetting.savePaperSizeTypePear((MediaInfo.PaperSizeType) this.mPaperSizeType);
        saveSupportedMediaFile();
        String str = this.autoConnectSsid;
        if (str == null || str.length() <= 0) {
            WiFiDirectManager.resetConnectInfo(this, WiFiDirectManager.DEVICE_TYPE_PRINTER);
        } else {
            WiFiDirectManager.setConnectInfo(this, this.autoConnectSsid, WiFiDirectManager.DEVICE_TYPE_PRINTER, myPrinter.getName());
        }
        EPPrinterManager ePPrinterManager = new EPPrinterManager(this.mContext);
        ePPrinterManager.commitIPPrinterInfo();
        ePPrinterManager.commitRemotePrinterInfo();
        refreshRemoteServiceRemotePrinter();
        if (this.mPrinterSelectDone) {
            new InkRplnRepository(false).savePermanently(this);
        }
    }

    private void refreshRemoteServiceRemotePrinter() {
        IEpsonService iEpsonService = this.mEpsonService;
        if (iEpsonService != null) {
            try {
                iEpsonService.refreshRemotePrinterLogin();
            } catch (RemoteException unused) {
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onDestroy() {
        super.onDestroy();
        unbindEpsonService();
        EPLog.i("SettingScr", "onDestroy");
        this.mPaperSizeType.destructor();
    }

    private void bindEpsonService() {
        EPLog.m316v("SettingScr", "bindEpsonService");
        if (this.mEpsonService == null) {
            bindService(new Intent(this, EpsonService.class), this.mEpsonConnection, 1);
        }
    }

    private void unbindEpsonService() {
        EPLog.m316v("SettingScr", "unbindEpsonService");
        IEpsonService iEpsonService = this.mEpsonService;
        if (iEpsonService != null) {
            try {
                iEpsonService.unregisterCallback(this.mCallback);
                unbindService(this.mEpsonConnection);
                this.mEpsonService = null;
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void onClick(View view) {
        if (this.progressGetOption.getVisibility() == 8) {
            IEpsonService iEpsonService = this.mEpsonService;
            if (iEpsonService != null) {
                try {
                    iEpsonService.cancelSearchPrinter();
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
            switch (view.getId()) {
                case R.id.apf_setting_layout /*2131230819*/:
                    launchDetailScreen(this.photoApfValueForLocalPrinter, R.id.apf_setting_layout);
                    return;
                case R.id.brightness_minus_button /*2131230848*/:
                    this.brightnessValue--;
                    if (this.brightnessValue <= -50) {
                        this.brightnessValue = -50;
                        this.brightnessMinus.setEnabled(false);
                    } else {
                        this.brightnessMinus.setEnabled(true);
                    }
                    this.brightnessPlus.setEnabled(true);
                    this.brightness.setText(String.valueOf(this.brightnessValue));
                    return;
                case R.id.brightness_plus_button /*2131230850*/:
                    this.brightnessValue++;
                    if (this.brightnessValue >= 50) {
                        this.brightnessValue = 50;
                        this.brightnessPlus.setEnabled(false);
                    } else {
                        this.brightnessPlus.setEnabled(true);
                    }
                    this.brightnessMinus.setEnabled(true);
                    this.brightness.setText(String.valueOf(this.brightnessValue));
                    return;
                case R.id.color /*2131230930*/:
                    launchDetailScreen(this.color, R.id.color);
                    return;
                case R.id.contrast_minus_button /*2131230942*/:
                    this.contrastValue--;
                    if (this.contrastValue <= -50) {
                        this.contrastValue = -50;
                        this.contrastMinus.setEnabled(false);
                    } else {
                        this.contrastMinus.setEnabled(true);
                    }
                    this.contrastPlus.setEnabled(true);
                    this.contrast.setText(String.valueOf(this.contrastValue));
                    return;
                case R.id.contrast_plus_button /*2131230943*/:
                    this.contrastValue++;
                    if (this.contrastValue >= 50) {
                        this.contrastValue = 50;
                        this.contrastPlus.setEnabled(false);
                    } else {
                        this.contrastPlus.setEnabled(true);
                    }
                    this.contrastMinus.setEnabled(true);
                    this.contrast.setText(String.valueOf(this.contrastValue));
                    return;
                case R.id.copies_minus_button /*2131230945*/:
                    this.copiesValue--;
                    if (this.copiesValue <= 1) {
                        this.copiesValue = 1;
                        this.copiesMinus.setEnabled(false);
                    } else {
                        this.copiesMinus.setEnabled(true);
                    }
                    this.copiesPlus.setEnabled(true);
                    this.copies.setText(String.valueOf(this.copiesValue));
                    return;
                case R.id.copies_plus_button /*2131230946*/:
                    this.copiesValue++;
                    if (this.copiesValue >= 30) {
                        this.copiesValue = 30;
                        this.copiesPlus.setEnabled(false);
                    } else {
                        this.copiesPlus.setEnabled(true);
                    }
                    this.copiesMinus.setEnabled(true);
                    this.copies.setText(String.valueOf(this.copiesValue));
                    return;
                case R.id.duplex /*2131231005*/:
                    launchDetailScreen(this.duplex, R.id.duplex);
                    return;
                case R.id.feed_direction /*2131231037*/:
                    launchDetailScreen(this.feedDirection, R.id.feed_direction);
                    return;
                case R.id.layout /*2131231158*/:
                    launchDetailScreen(this.layout, R.id.layout);
                    return;
                case R.id.page_range_setting /*2131231300*/:
                    Intent intent = new Intent(this, PageRangeSetting.class);
                    intent.putExtra("SHEETS", this.sheets);
                    intent.putExtra("printAll", this.printAll);
                    intent.putExtra("startValue", this.startValue);
                    intent.putExtra("endValue", this.endValue);
                    startActivityForResult(intent, 2);
                    return;
                case R.id.paper_size /*2131231306*/:
                    launchDetailScreen(this.paperSize, R.id.paper_size);
                    return;
                case R.id.paper_source /*2131231311*/:
                    int i = this.paperSource;
                    int[] iArr = this.paper_source_info;
                    if (iArr != null && iArr.length <= 1) {
                        i = 128;
                    }
                    launchDetailScreen(i, R.id.paper_source);
                    return;
                case R.id.paper_type /*2131231314*/:
                    launchDetailScreen(this.paperType, R.id.paper_type);
                    return;
                case R.id.printdate /*2131231355*/:
                    launchDetailScreen(this.printdate, R.id.printdate);
                    return;
                case R.id.printer /*2131231358*/:
                    unbindEpsonService();
                    new AsyncTask<Void, Void, Void>() {
                        /* access modifiers changed from: protected */
                        public void onPreExecute() {
                            SettingScr.this.findViewById(R.id.printer).setClickable(false);
                        }

                        /* access modifiers changed from: protected */
                        public Void doInBackground(Void... voidArr) {
                            SettingScr settingScr = SettingScr.this;
                            WiFiDirectManager.disconnect(settingScr, WiFiDirectManager.DEVICE_TYPE_PRINTER, settingScr.printerIp);
                            SettingScr settingScr2 = SettingScr.this;
                            WiFiDirectManager.disconnectSimpleAP(settingScr2, settingScr2.autoConnectSsid, SettingScr.this.printerIp);
                            return null;
                        }

                        /* access modifiers changed from: protected */
                        public void onPostExecute(Void voidR) {
                            Intent intent = new Intent(SettingScr.this, SearchPrinterScr.class);
                            Bundle bundle = new Bundle();
                            bundle.putString(Constants.PRINTER_ID, SettingScr.this.printerId);
                            bundle.putString(Constants.PRINTER_IP, SettingScr.this.printerIp);
                            bundle.putString(Constants.PRINTER_EMAIL_ADDRESS, SettingScr.this.printerEmailAddress);
                            bundle.putInt(Constants.PRINTER_LOCATION, SettingScr.this.printerLocation);
                            bundle.putString(SettingScr.EXTRA_SIMPLEAP, SettingScr.this.autoConnectSsid);
                            intent.putExtras(bundle);
                            SettingScr.this.startActivityForResult(intent, 0);
                            SettingScr.this.findViewById(R.id.printer).setClickable(true);
                        }
                    }.execute(new Void[0]);
                    return;
                case R.id.quality /*2131231392*/:
                    launchDetailScreen(this.quality, R.id.quality);
                    return;
                case R.id.saturation_minus_button /*2131231425*/:
                    this.saturationValue--;
                    if (this.saturationValue <= -50) {
                        this.saturationValue = -50;
                        this.saturationMinus.setEnabled(false);
                    } else {
                        this.saturationMinus.setEnabled(true);
                    }
                    this.saturationPlus.setEnabled(true);
                    this.saturation.setText(String.valueOf(this.saturationValue));
                    return;
                case R.id.saturation_plus_button /*2131231426*/:
                    this.saturationValue++;
                    if (this.saturationValue >= 50) {
                        this.saturationValue = 50;
                        this.saturationPlus.setEnabled(false);
                    } else {
                        this.saturationPlus.setEnabled(true);
                    }
                    this.saturationMinus.setEnabled(true);
                    this.saturation.setText(String.valueOf(this.saturationValue));
                    return;
                case R.id.sharpness_setting_layout /*2131231482*/:
                    launchDetailScreen(this.mSharpnessValue, R.id.sharpness_setting_layout);
                    return;
                default:
                    return;
            }
        }
    }

    private void launchDetailScreen(int i, int i2) {
        Intent intent = new Intent(this, PrinterInfoDetail.class);
        Bundle bundle = new Bundle();
        bundle.putInt("ID", i2);
        bundle.putInt("sizeIndex", this.sizeIndex);
        bundle.putInt("typeIndex", this.typeIndex);
        bundle.putInt("curValue", i);
        bundle.putBoolean("isDocumentSetting", this.isDocumentSetting);
        switch (i2) {
            case R.id.color /*2131230930*/:
                bundle.putIntArray(Constants.COLOR_INFO, this.color_info);
                break;
            case R.id.duplex /*2131231005*/:
                bundle.putIntArray(Constants.DUPLEX_INFO, this.duplex_info);
                break;
            case R.id.layout /*2131231158*/:
                bundle.putIntArray(Constants.LAYOUT_INFO, this.layout_info);
                break;
            case R.id.paper_size /*2131231306*/:
                bundle.putIntArray(Constants.PAPER_SIZE_INFO, this.paper_size_info);
                break;
            case R.id.paper_source /*2131231311*/:
                int[] iArr = this.paper_source_info;
                bundle.putIntArray(Constants.PAPER_SOURCE_INFO, (iArr == null || iArr.length > 1) ? this.paper_source_info : new int[]{128});
                break;
            case R.id.paper_type /*2131231314*/:
                bundle.putIntArray(Constants.PAPER_TYPE_INFO, this.paper_type_info);
                break;
            case R.id.quality /*2131231392*/:
                bundle.putIntArray(Constants.PRINT_QUALITY_INFO, this.quality_info);
                break;
        }
        intent.putExtras(bundle);
        startActivityForResult(intent, 1);
    }

    /* access modifiers changed from: protected */
    public void onActivityResult(int i, int i2, Intent intent) {
        super.onActivityResult(i, i2, intent);
        String callingPackage = getCallingPackage();
        EPLog.i(callingPackage, "requestCode = " + i + " resultCode = " + i2);
        if (i != 0) {
            if (i != 4) {
                if (i != 2) {
                    int i3 = 1;
                    if (i == 1 && i2 == -1) {
                        int i4 = intent.getExtras().getInt("curValue");
                        switch (intent.getExtras().getInt("ID")) {
                            case R.id.apf_setting_layout /*2131230819*/:
                                if (i4 != 1) {
                                    i3 = 0;
                                }
                                this.photoApfValueForLocalPrinter = i3;
                                displayApfState(this.photoApfValueForLocalPrinter);
                                break;
                            case R.id.color /*2131230930*/:
                                this.mLookupTable = new MediaInfo.Color();
                                this.colorInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                this.color = i4;
                                break;
                            case R.id.duplex /*2131231005*/:
                                this.mLookupTable = new MediaInfo.Duplex();
                                this.duplexInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                this.duplex = i4;
                                break;
                            case R.id.feed_direction /*2131231037*/:
                                this.mLookupTable = new MediaInfo.FeedDirection();
                                this.feedDirectionInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                this.feedDirection = i4;
                                break;
                            case R.id.layout /*2131231158*/:
                                this.mLookupTable = new LayoutEx();
                                this.layoutInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                this.layout = i4;
                                this.undoFlag = false;
                                this.mHandler.sendEmptyMessage(32);
                                break;
                            case R.id.paper_size /*2131231306*/:
                                this.sizeIndex = intent.getExtras().getInt("INDEX");
                                this.mLookupTable = new MediaInfo.PaperSize();
                                this.paperSizeInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                this.paperSize = i4;
                                this.paperType = this.mPaperSizeType.getID(this.paperSize);
                                this.undoFlag = false;
                                this.mHandler.sendEmptyMessage(2);
                                break;
                            case R.id.paper_source /*2131231311*/:
                                this.mLookupTable = new MediaInfo.PaperSource();
                                this.paperSourceInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                int[] iArr = this.paper_source_info;
                                if (iArr != null && iArr.length > 1) {
                                    this.paperSource = i4;
                                }
                                this.undoFlag = false;
                                this.mHandler.sendEmptyMessage(32);
                                break;
                            case R.id.paper_type /*2131231314*/:
                                this.typeIndex = intent.getExtras().getInt("INDEX");
                                this.mLookupTable = new MediaInfo.PaperType();
                                this.paperTypeInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                this.paperType = i4;
                                this.mPaperSizeType.putID(this.paperSize, this.paperType);
                                this.undoFlag = false;
                                this.mHandler.sendEmptyMessage(3);
                                break;
                            case R.id.printdate /*2131231355*/:
                                this.mLookupTable = new MediaInfo.PrintDate();
                                this.printDateInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                this.printdate = i4;
                                break;
                            case R.id.quality /*2131231392*/:
                                this.mLookupTable = new MediaInfo.Quality();
                                this.qualityInfo.setText(getString(this.mLookupTable.getStringId(i4)));
                                this.mLookupTable.destructor();
                                this.quality = i4;
                                break;
                            case R.id.sharpness_setting_layout /*2131231482*/:
                                if (i4 != 1) {
                                    i3 = 0;
                                }
                                this.mSharpnessValue = i3;
                                displaySharpnessState(this.mSharpnessValue);
                                break;
                        }
                    }
                } else if (i2 == -1) {
                    this.printAll = intent.getExtras().getBoolean("printAll");
                    this.startValue = intent.getExtras().getInt("startValue");
                    this.endValue = intent.getExtras().getInt("endValue");
                    this.mHandler.sendEmptyMessage(64);
                }
            } else {
                endInkReplAndGoProbePrinter();
            }
        } else {
            onPrinterSelectEnd(i2, intent);
        }
        updatePrinterIcon();
    }

    /* JADX WARNING: Can't fix incorrect switch cases order */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x00ea, code lost:
        if (r7.loadIpPrinterInfo(r6.printerId) == null) goto L_0x00f7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x00f3, code lost:
        if (r7.loadRemotePrinterInfo(r6.printerEmailAddress) == null) goto L_0x00f7;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private void onPrinterSelectEnd(int r7, android.content.Intent r8) {
        /*
            r6 = this;
            r0 = 0
            r1 = 1
            r2 = -1
            if (r7 != r2) goto L_0x00d6
            android.os.Bundle r7 = r8.getExtras()
            java.lang.String r2 = "myprinter"
            android.os.Parcelable r7 = r7.getParcelable(r2)
            epson.print.MyPrinter r7 = (epson.print.MyPrinter) r7
            r6.printer = r7
            android.widget.TextView r7 = r6.printerName
            epson.print.MyPrinter r2 = r6.printer
            java.lang.String r2 = r2.getName()
            r7.setText(r2)
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getName()
            r6.printerDeviceId = r7
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getPrinterId()
            r6.printerId = r7
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getIp()
            r6.printerIp = r7
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getSerialNo()
            r6.printerSerialNo = r7
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getEmailAddress()
            r6.printerEmailAddress = r7
            epson.print.MyPrinter r7 = r6.printer
            int r7 = r7.getLocation()
            r6.printerLocation = r7
            epson.print.EPPrinterManager r7 = new epson.print.EPPrinterManager
            r7.<init>(r6)
            int r2 = r6.printerLocation
            switch(r2) {
                case 2: goto L_0x0075;
                case 3: goto L_0x0059;
                default: goto L_0x0058;
            }
        L_0x0058:
            goto L_0x0090
        L_0x0059:
            java.lang.String r2 = r6.printerId
            epson.print.EPPrinterInfo r7 = r7.loadIpPrinterInfo(r2)
            if (r7 == 0) goto L_0x0090
            java.lang.String r2 = r7.userDefName
            if (r2 == 0) goto L_0x0090
            java.lang.String r2 = r7.userDefName
            int r2 = r2.length()
            if (r2 <= 0) goto L_0x0090
            android.widget.TextView r2 = r6.printerName
            java.lang.String r7 = r7.userDefName
            r2.setText(r7)
            goto L_0x0090
        L_0x0075:
            java.lang.String r2 = r6.printerEmailAddress
            epson.print.EPPrinterInfo r7 = r7.loadRemotePrinterInfo(r2)
            if (r7 == 0) goto L_0x0090
            java.lang.String r2 = r7.userDefName
            if (r2 == 0) goto L_0x0090
            java.lang.String r2 = r7.userDefName
            int r2 = r2.length()
            if (r2 <= 0) goto L_0x0090
            android.widget.TextView r2 = r6.printerName
            java.lang.String r7 = r7.userDefName
            r2.setText(r7)
        L_0x0090:
            android.os.Bundle r7 = r8.getExtras()
            java.lang.String r8 = "simpleap"
            java.lang.String r7 = r7.getString(r8)
            r6.autoConnectSsid = r7
            android.content.Context r7 = r6.getApplicationContext()
            java.lang.String r8 = "PrintSetting"
            java.lang.String r2 = "RE_SEARCH"
            epson.common.Utils.savePref((android.content.Context) r7, (java.lang.String) r8, (java.lang.String) r2, (boolean) r1)
            r6.undoFlag = r0
            r6.mPrinterSelectDone = r1
            r6.mWaiteInkReplenProgress = r1
            android.content.Context r7 = r6.getApplicationContext()
            java.lang.String r8 = r6.printerId
            boolean r7 = epson.print.inkrpln.InkReplnHelper.isSimpleApOrP2p(r7, r8)
            if (r7 != 0) goto L_0x00d2
            epson.print.inkrpln.PrintSettingDependencyBuilder r7 = new epson.print.inkrpln.PrintSettingDependencyBuilder
            java.lang.String r1 = r6.printerId
            java.lang.String r2 = r6.printerIp
            java.lang.String r3 = r6.printerSerialNo
            int r4 = r6.printerLocation
            java.lang.String r5 = r6.printerDeviceId
            r0 = r7
            r0.<init>(r1, r2, r3, r4, r5)
            android.content.Intent r7 = epson.print.inkrpln.InkRplnProgressDialog.getStartIntent2(r6, r7)
            r8 = 4
            r6.startActivityForResult(r7, r8)
            goto L_0x00fc
        L_0x00d2:
            r6.endInkReplAndGoProbePrinter()
            goto L_0x00fc
        L_0x00d6:
            r6.bindEpsonService()
            epson.print.EPPrinterManager r7 = new epson.print.EPPrinterManager
            r7.<init>(r6)
            int r8 = r6.printerLocation
            switch(r8) {
                case 2: goto L_0x00ed;
                case 3: goto L_0x00e4;
                default: goto L_0x00e3;
            }
        L_0x00e3:
            goto L_0x00f6
        L_0x00e4:
            java.lang.String r8 = r6.printerId
            epson.print.EPPrinterInfo r7 = r7.loadIpPrinterInfo(r8)
            if (r7 != 0) goto L_0x00f6
            goto L_0x00f7
        L_0x00ed:
            java.lang.String r8 = r6.printerEmailAddress
            epson.print.EPPrinterInfo r7 = r7.loadRemotePrinterInfo(r8)
            if (r7 != 0) goto L_0x00f6
            goto L_0x00f7
        L_0x00f6:
            r1 = 0
        L_0x00f7:
            if (r1 == 0) goto L_0x00fc
            r6.resetSettings()
        L_0x00fc:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: epson.print.screen.SettingScr.onPrinterSelectEnd(int, android.content.Intent):void");
    }

    private void endInkReplAndGoProbePrinter() {
        this.mWaiteInkReplenProgress = false;
        bindEpsonService();
        this.mHandler.sendEmptyMessageDelayed(17, 100);
    }

    private void updateSettingView() {
        int i = 8;
        if (this.isDocumentSetting) {
            if (this.printerLocation != 2) {
                setVisibilityPageRange(true);
                setClickablePageRange(true);
            } else if (!this.enableShowPreview) {
                setVisibilityPageRange(false);
            } else if (this.disablePrintArea) {
                setVisibilityPageRange(true);
                setClickablePageRange(false);
            } else {
                setVisibilityPageRange(true);
                setClickablePageRange(true);
            }
            if (this.sheets == 1) {
                ((ImageView) findViewById(R.id.page_range_next_screen_imv)).setVisibility(8);
            } else {
                ((ImageView) findViewById(R.id.page_range_next_screen_imv)).setVisibility(0);
            }
        } else {
            setVisibilityPageRange(false);
        }
        int[] iArr = this.color_info;
        if (iArr == null) {
            ((ImageView) findViewById(R.id.color_next_screen_imv)).setVisibility(8);
        } else if (iArr.length <= 1) {
            ((ImageView) findViewById(R.id.color_next_screen_imv)).setVisibility(8);
        } else {
            ((ImageView) findViewById(R.id.color_next_screen_imv)).setVisibility(0);
        }
        int[] iArr2 = this.duplex_info;
        if (iArr2 == null) {
            findViewById(R.id.duplex_view).setVisibility(8);
            ((LinearLayout) findViewById(R.id.duplex)).setVisibility(8);
        } else if (iArr2.length <= 1) {
            findViewById(R.id.duplex_view).setVisibility(8);
            ((LinearLayout) findViewById(R.id.duplex)).setVisibility(8);
        } else {
            findViewById(R.id.duplex_view).setVisibility(0);
            ((LinearLayout) findViewById(R.id.duplex)).setVisibility(0);
        }
        switch (this.lang) {
            case 2:
            case 3:
                findViewById(R.id.feed_direction_view).setVisibility(0);
                findViewById(R.id.feed_direction).setVisibility(0);
                break;
            default:
                findViewById(R.id.feed_direction_view).setVisibility(8);
                findViewById(R.id.feed_direction).setVisibility(8);
                break;
        }
        if (this.isDocumentSetting || this.printerLocation == 2) {
            findViewById(R.id.printdate).setVisibility(8);
        } else {
            findViewById(R.id.printdate).setVisibility(0);
        }
        if (this.printerLocation != 2 && !this.isDocumentSetting) {
            i = 0;
        }
        findViewById(R.id.viewGroupPhotoEffect).setVisibility(i);
        findViewById(R.id.apf_setting_layout).setVisibility(i);
        findViewById(R.id.sharpness_setting_layout).setVisibility(i);
    }

    private int getPrinterLang() {
        int i;
        IEpsonService iEpsonService;
        if (!(this.printerLocation == 2 || (iEpsonService = this.mEpsonService) == null)) {
            try {
                i = iEpsonService.getLang();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
            EPLog.d("PrintSetting", "getPrinterLang called : ret = " + i);
            return i;
        }
        i = 1;
        EPLog.d("PrintSetting", "getPrinterLang called : ret = " + i);
        return i;
    }

    private void setVisibilityPageRange(boolean z) {
        int i = 0;
        findViewById(R.id.page_range_setting).setVisibility(z ? 0 : 8);
        View findViewById = findViewById(R.id.page_range_separator);
        if (!z) {
            i = 8;
        }
        findViewById.setVisibility(i);
    }

    private void setClickablePageRange(boolean z) {
        findViewById(R.id.page_range_setting).setClickable(z);
        int i = 0;
        findViewById(R.id.page_range_next_screen_imv).setVisibility(z ? 0 : 8);
        View findViewById = findViewById(R.id.page_range_value);
        if (!z) {
            i = 8;
        }
        findViewById.setVisibility(i);
    }

    private void resetSettings() {
        this.printerDeviceId = null;
        this.printerId = null;
        this.printerEmailAddress = null;
        this.printerIp = null;
        this.printerLocation = 0;
        this.info = null;
        this.paper_source_info = null;
        this.color_info = null;
        this.paper_size_info = null;
        this.paper_type_info = null;
        this.layout_info = null;
        this.quality_info = null;
        this.duplex_info = null;
        this.autoConnectSsid = "";
        this.printerName.setText(getString(R.string.str_lbl_title_scan));
        ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setVisibility(8);
        updateSettingView();
        setScreenState(true);
    }

    public void onBackPressed() {
        super.onBackPressed();
        this.mFinishRequested = true;
        IEpsonService iEpsonService = this.mEpsonService;
        if (iEpsonService != null) {
            try {
                iEpsonService.cancelSearchPrinter();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        loadSupportedMediaFile();
        EPPrinterManager ePPrinterManager = new EPPrinterManager(this.mContext);
        ePPrinterManager.rollbackRemotePrinterInfo();
        ePPrinterManager.rollbackIPPrinterInfo();
        new InkRplnRepository(false).deleteTemporaryData(this);
    }

    /* access modifiers changed from: private */
    public void setScreenState(Boolean bool) {
        if (bool.booleanValue()) {
            this.progressGetOption.setVisibility(8);
        } else {
            this.progressGetOption.setVisibility(0);
        }
        findViewById(R.id.printer).setClickable(bool.booleanValue());
        findViewById(R.id.paper_size).setClickable(bool.booleanValue());
        findViewById(R.id.paper_type).setClickable(bool.booleanValue());
        findViewById(R.id.layout).setClickable(bool.booleanValue());
        findViewById(R.id.quality).setClickable(bool.booleanValue());
        findViewById(R.id.paper_source).setClickable(bool.booleanValue());
        findViewById(R.id.color).setClickable(bool.booleanValue());
        findViewById(R.id.duplex).setClickable(bool.booleanValue());
        findViewById(R.id.feed_direction).setClickable(bool.booleanValue());
        findViewById(R.id.printdate).setClickable(bool.booleanValue());
    }

    public void showErrorDialog(String str, String str2) {
        new CustomTitleAlertDialogBuilder(this).setCancelable(false).setTitle(str).setMessage(str2).setNegativeButton(getString(R.string.f343ok), new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialogInterface, int i) {
                SettingScr.this.setScreenState(true);
                dialogInterface.cancel();
            }
        }).create().show();
        updateSupportedMediaFile(true);
    }

    /* access modifiers changed from: protected */
    public void onResume() {
        super.onResume();
        EPLog.m307e("SettingScr", "onResume()");
        if (this.printerId != null && this.printerLocation == 1 && this.isRetryAfterConnectSimpleAp && !this.mWaiteInkReplenProgress) {
            this.undoFlag = false;
            if (loadSupportedMediaFile()) {
                this.mHandler.sendEmptyMessage(1);
            } else {
                this.mHandler.sendEmptyMessage(17);
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onPause() {
        EPLog.d("SettingScr", "onPause");
        super.onPause();
        if (isFinishing()) {
            this.mFinishRequested = true;
            deleteLongTapMessage();
        }
        WiFiDirectManager.disconnect(this, WiFiDirectManager.DEVICE_TYPE_PRINTER, this.printerIp);
        WiFiDirectManager.disconnectSimpleAP(this, this.autoConnectSsid, this.printerIp);
    }

    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.C2138menu.menu_done, menu);
        return super.onCreateOptionsMenu(menu);
    }

    public boolean onOptionsItemSelected(MenuItem menuItem) {
        if (menuItem.getItemId() != R.id.menuSettingsDone) {
            return super.onOptionsItemSelected(menuItem);
        }
        saveChanged();
        setResult(3, getIntent());
        finish();
        return true;
    }

    /* access modifiers changed from: protected */
    public void deleteLongTapMessage() {
        MotionEvent obtain = MotionEvent.obtain(SystemClock.uptimeMillis(), SystemClock.uptimeMillis() + 10, 1, 0.0f, 0.0f, 0);
        this.copiesMinus.dispatchTouchEvent(obtain);
        this.copiesPlus.dispatchTouchEvent(obtain);
    }

    public void onConfigurationChanged(Configuration configuration) {
        super.onConfigurationChanged(configuration);
        deleteLongTapMessage();
    }
}
